#!/bin/sh
# the next line restarts using wish\
exec wish "$0" "$@" 

if {![info exists vTcl(sourcing)]} {

    switch $tcl_platform(platform) {
	windows {
            option add *Button.padY 0
	}
	default {
	    option add *Scrollbar.width 10
            option add *Scrollbar.highlightThickness 0
            option add *Scrollbar.elementBorderWidth 2
            option add *Scrollbar.borderWidth 2
	}
    }
    
}

#############################################################################
# Visual Tcl v1.60 Project
#

#################################
# VTCL LIBRARY PROCEDURES
#

if {![info exists vTcl(sourcing)]} {
#############################################################################
## Library Procedure:  Window

proc {Window} {args} {
    global vTcl
    set cmd     [lindex $args 0]
    set name    [lindex $args 1]
    set newname [lindex $args 2]
    set rest    [lrange $args 3 end]
    if {$name == "" || $cmd == ""} { return }
    if {$newname == ""} { set newname $name }
    if {$name == "."} { wm withdraw $name; return }
    set exists [winfo exists $newname]
    switch $cmd {
        show {
            if {$exists} {
                wm deiconify $newname
            } elseif {[info procs vTclWindow$name] != ""} {
                eval "vTclWindow$name $newname $rest"
            }
            if {[winfo exists $newname] && [wm state $newname] == "normal"} {
                vTcl:FireEvent $newname <<Show>>
            }
        }
        hide    {
            if {$exists} {
                wm withdraw $newname
                vTcl:FireEvent $newname <<Hide>>
                return}
        }
        iconify { if $exists {wm iconify $newname; return} }
        destroy { if $exists {destroy $newname; return} }
    }
}
#############################################################################
## Library Procedure:  vTcl:DefineAlias

proc {vTcl:DefineAlias} {target alias widgetProc top_or_alias cmdalias} {
    global widget
    set widget($alias) $target
    set widget(rev,$target) $alias
    if {$cmdalias} {
        interp alias {} $alias {} $widgetProc $target
    }
    if {$top_or_alias != ""} {
        set widget($top_or_alias,$alias) $target
        if {$cmdalias} {
            interp alias {} $top_or_alias.$alias {} $widgetProc $target
        }
    }
}
#############################################################################
## Library Procedure:  vTcl:DoCmdOption

proc {vTcl:DoCmdOption} {target cmd} {

    ## menus are considered toplevel windows
    set parent $target
    while {[winfo class $parent] == "Menu"} {
        set parent [winfo parent $parent]
    }

    regsub -all {\%widget} $cmd $target cmd
    regsub -all {\%top} $cmd [winfo toplevel $parent] cmd

    uplevel #0 [list eval $cmd]
}
#############################################################################
## Library Procedure:  vTcl:FireEvent

proc {vTcl:FireEvent} {target event {params {}}} {
    ## The window may have disappeared
    if {![winfo exists $target]} return
    ## Process each binding tag, looking for the event
    foreach bindtag [bindtags $target] {
        set tag_events [bind $bindtag]
        set stop_processing 0
        foreach tag_event $tag_events {
            if {$tag_event == $event} {
                set bind_code [bind $bindtag $tag_event]
                foreach rep "\{%W $target\} $params" {
                    regsub -all [lindex $rep 0] $bind_code [lindex $rep 1] bind_code
                }
                set result [catch {uplevel #0 $bind_code} errortext]
                if {$result == 3} {
                    ## break exception, stop processing
                    set stop_processing 1
                } elseif {$result != 0} {
                    bgerror $errortext
                }
                break
            }
        }
        if {$stop_processing} {break}
    }
}
#############################################################################
## Library Procedure:  vTcl:Toplevel:WidgetProc

proc {vTcl:Toplevel:WidgetProc} {w args} {
    if {[llength $args] == 0} {
        ## If no arguments, returns the path the alias points to
        return $w
    }
    ## The first argument is a switch, they must be doing a configure.
    if {[string index $args 0] == "-"} {
        set command configure
        ## There's only one argument, must be a cget.
        if {[llength $args] == 1} {
            set command cget
        }
    } else {
        set command [lindex $args 0]
        set args [lrange $args 1 end]
    }
    switch -- $command {
        "hide" - "Hide" - "show" - "Show" {
            Window [string tolower $command] $w
        }
        "ShowModal" {
            Window show $w
            raise $w
            grab $w
            tkwait window $w
            grab release $w
        }
        default {
            uplevel $w $command $args
        }
    }
}
#############################################################################
## Library Procedure:  vTcl:WidgetProc

proc {vTcl:WidgetProc} {w args} {
    if {[llength $args] == 0} {
        ## If no arguments, returns the path the alias points to
        return $w
    }
    ## The first argument is a switch, they must be doing a configure.
    if {[string index $args 0] == "-"} {
        set command configure
        ## There's only one argument, must be a cget.
        if {[llength $args] == 1} {
            set command cget
        }
    } else {
        set command [lindex $args 0]
        set args [lrange $args 1 end]
    }
    uplevel $w $command $args
}
#############################################################################
## Library Procedure:  vTcl:toplevel

proc {vTcl:toplevel} {args} {
    uplevel #0 eval toplevel $args
    set target [lindex $args 0]
    namespace eval ::$target {}
}
}


if {[info exists vTcl(sourcing)]} {

proc vTcl:project:info {} {
    namespace eval ::widgets::.top17 {
        array set save {-background 1 -highlightbackground 1 -highlightcolor 1}
        set set,origin 1
        set set,size 1
    }
    namespace eval ::widgets::.top17.fra18 {
        array set save {-background 1 -borderwidth 1 -height 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -width 1}
    }
    namespace eval ::widgets::.top17.fra18.lab21 {
        array set save {-activebackground 1 -activeforeground 1 -background 1 -borderwidth 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -text 1}
    }
    namespace eval ::widgets::.top17.fra18.ent22 {
        array set save {-background 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -insertbackground 1 -selectbackground 1 -selectforeground 1}
    }
    namespace eval ::widgets::.top17.fra18.lab25 {
        array set save {-activebackground 1 -activeforeground 1 -background 1 -borderwidth 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -text 1}
    }
    namespace eval ::widgets::.top17.fra18.ent26 {
        array set save {-background 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -insertbackground 1 -selectbackground 1 -selectforeground 1}
    }
    namespace eval ::widgets::.top17.fra18.lab27 {
        array set save {-activebackground 1 -activeforeground 1 -background 1 -borderwidth 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -text 1}
    }
    namespace eval ::widgets::.top17.fra18.ent28 {
        array set save {-background 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -insertbackground 1 -selectbackground 1 -selectforeground 1}
    }
    namespace eval ::widgets::.top17.fra19 {
        array set save {-background 1 -borderwidth 1 -height 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -width 1}
    }
    namespace eval ::widgets::.top17.fra19.ent23 {
        array set save {-background 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -insertbackground 1 -selectbackground 1 -selectforeground 1}
    }
    namespace eval ::widgets::.top17.fra29 {
        array set save {-background 1 -borderwidth 1 -height 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -width 1}
    }
    namespace eval ::widgets::.top17.fra29.fra30 {
        array set save {-background 1 -borderwidth 1 -height 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -width 1}
    }
    namespace eval ::widgets::.top17.fra29.fra30.ent32 {
        array set save {-background 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -insertbackground 1 -selectbackground 1 -selectforeground 1 -state 1}
    }
    namespace eval ::widgets::.top17.fra29.fra30.ent35 {
        array set save {-background 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -insertbackground 1 -selectbackground 1 -selectforeground 1}
    }
    namespace eval ::widgets::.top17.fra29.fra30.cpd24 {
        array set save {-background 1 -borderwidth 1 -height 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -width 1}
    }
    namespace eval ::widgets::.top17.fra29.fra30.cpd24.01 {
        array set save {-background 1 -font 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -selectbackground 1 -selectforeground 1 -xscrollcommand 1 -yscrollcommand 1}
    }
    namespace eval ::widgets::.top17.fra29.fra30.cpd24.02 {
        array set save {-activebackground 1 -background 1 -borderwidth 1 -command 1 -cursor 1 -highlightbackground 1 -highlightcolor 1 -orient 1 -troughcolor 1 -width 1}
    }
    namespace eval ::widgets::.top17.fra29.fra30.cpd24.03 {
        array set save {-activebackground 1 -background 1 -borderwidth 1 -command 1 -cursor 1 -highlightbackground 1 -highlightcolor 1 -troughcolor 1 -width 1}
    }
    namespace eval ::widgets::.top17.fra29.fra36 {
        array set save {-background 1 -borderwidth 1 -height 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -width 1}
    }
    namespace eval ::widgets::.top17.fra29.fra36.ent37 {
        array set save {-background 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -insertbackground 1 -selectbackground 1 -selectforeground 1 -state 1}
    }
    namespace eval ::widgets::.top17.fra29.fra36.ent38 {
        array set save {-background 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -insertbackground 1 -selectbackground 1 -selectforeground 1}
    }
    namespace eval ::widgets::.top17.fra29.fra36.cpd25 {
        array set save {-background 1 -borderwidth 1 -height 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -width 1}
    }
    namespace eval ::widgets::.top17.fra29.fra36.cpd25.01 {
        array set save {-background 1 -font 1 -foreground 1 -height 1 -highlightbackground 1 -highlightcolor 1 -selectbackground 1 -selectforeground 1 -xscrollcommand 1 -yscrollcommand 1}
    }
    namespace eval ::widgets::.top17.fra29.fra36.cpd25.02 {
        array set save {-activebackground 1 -background 1 -borderwidth 1 -command 1 -cursor 1 -highlightbackground 1 -highlightcolor 1 -orient 1 -troughcolor 1 -width 1}
    }
    namespace eval ::widgets::.top17.fra29.fra36.cpd25.03 {
        array set save {-activebackground 1 -background 1 -borderwidth 1 -command 1 -cursor 1 -highlightbackground 1 -highlightcolor 1 -troughcolor 1 -width 1}
    }
    namespace eval ::widgets::.top17.fra29.ent39 {
        array set save {-background 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -insertbackground 1 -selectbackground 1 -selectforeground 1}
    }
    namespace eval ::widgets::.top17.fra29.ent40 {
        array set save {-background 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -insertbackground 1 -selectbackground 1 -selectforeground 1}
    }
    namespace eval ::widgets::.top17.fra29.ent41 {
        array set save {-background 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -insertbackground 1 -selectbackground 1 -selectforeground 1 -state 1}
    }
    namespace eval ::widgets::.top17.fra29.ent42 {
        array set save {-background 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -insertbackground 1 -selectbackground 1 -selectforeground 1}
    }
    namespace eval ::widgets::.top17.fra29.ent43 {
        array set save {-background 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -insertbackground 1 -selectbackground 1 -selectforeground 1}
    }
    namespace eval ::widgets::.top17.fra29.ent44 {
        array set save {-background 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -insertbackground 1 -selectbackground 1 -selectforeground 1}
    }
    namespace eval ::widgets::.top17.fra29.lab45 {
        array set save {-activebackground 1 -activeforeground 1 -background 1 -borderwidth 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -text 1}
    }
    namespace eval ::widgets::.top17.fra29.lab46 {
        array set save {-activebackground 1 -activeforeground 1 -background 1 -borderwidth 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -text 1}
    }
    namespace eval ::widgets::.top17.fra29.lab47 {
        array set save {-activebackground 1 -activeforeground 1 -background 1 -borderwidth 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -text 1}
    }
    namespace eval ::widgets::.top17.fra29.lab48 {
        array set save {-activebackground 1 -activeforeground 1 -background 1 -borderwidth 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -text 1}
    }
    namespace eval ::widgets::.top17.fra29.lab49 {
        array set save {-activebackground 1 -activeforeground 1 -background 1 -borderwidth 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -text 1}
    }
    namespace eval ::widgets::.top17.fra29.lab52 {
        array set save {-activebackground 1 -activeforeground 1 -background 1 -borderwidth 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -text 1}
    }
    namespace eval ::widgets::.top17.fra29.lab53 {
        array set save {-activebackground 1 -activeforeground 1 -background 1 -borderwidth 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -text 1}
    }
    namespace eval ::widgets::.top17.fra29.lab54 {
        array set save {-activebackground 1 -activeforeground 1 -background 1 -borderwidth 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -text 1}
    }
    namespace eval ::widgets::.top17.fra29.lab71 {
        array set save {-activebackground 1 -activeforeground 1 -background 1 -borderwidth 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -text 1}
    }
    namespace eval ::widgets::.top17.fra29.lab72 {
        array set save {-activebackground 1 -activeforeground 1 -background 1 -borderwidth 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -text 1}
    }
    namespace eval ::widgets::.top17.fra29.cpd22 {
        array set save {-background 1 -borderwidth 1 -height 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -width 1}
    }
    namespace eval ::widgets::.top17.fra29.cpd22.01 {
        array set save {-background 1 -font 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -selectbackground 1 -selectforeground 1 -xscrollcommand 1 -yscrollcommand 1}
    }
    namespace eval ::widgets::.top17.fra29.cpd22.02 {
        array set save {-activebackground 1 -background 1 -borderwidth 1 -command 1 -cursor 1 -highlightbackground 1 -highlightcolor 1 -orient 1 -troughcolor 1 -width 1}
    }
    namespace eval ::widgets::.top17.fra29.cpd22.03 {
        array set save {-activebackground 1 -background 1 -borderwidth 1 -command 1 -cursor 1 -highlightbackground 1 -highlightcolor 1 -troughcolor 1 -width 1}
    }
    namespace eval ::widgets::.top17.che60 {
        array set save {-activebackground 1 -activeforeground 1 -background 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -text 1 -variable 1}
    }
    namespace eval ::widgets::.top17.che61 {
        array set save {-activebackground 1 -activeforeground 1 -background 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -text 1 -variable 1}
    }
    namespace eval ::widgets::.top17.fra62 {
        array set save {-background 1 -borderwidth 1 -height 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -width 1}
    }
    namespace eval ::widgets::.top17.fra62.cpd17 {
        array set save {-background 1 -borderwidth 1 -height 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -width 1}
    }
    namespace eval ::widgets::.top17.fra62.cpd17.01 {
        array set save {-background 1 -font 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -selectbackground 1 -selectforeground 1 -xscrollcommand 1 -yscrollcommand 1}
    }
    namespace eval ::widgets::.top17.fra62.cpd17.02 {
        array set save {-activebackground 1 -background 1 -borderwidth 1 -command 1 -cursor 1 -highlightbackground 1 -highlightcolor 1 -orient 1 -troughcolor 1 -width 1}
    }
    namespace eval ::widgets::.top17.fra62.cpd17.03 {
        array set save {-activebackground 1 -background 1 -borderwidth 1 -command 1 -cursor 1 -highlightbackground 1 -highlightcolor 1 -troughcolor 1 -width 1}
    }
    namespace eval ::widgets::.top17.fra62.but19 {
        array set save {-activebackground 1 -activeforeground 1 -background 1 -command 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -text 1}
    }
    namespace eval ::widgets::.top17.fra62.but20 {
        array set save {-activebackground 1 -activeforeground 1 -background 1 -command 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -text 1}
    }
    namespace eval ::widgets::.top17.fra62.but21 {
        array set save {-activebackground 1 -activeforeground 1 -background 1 -command 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -text 1}
    }
    namespace eval ::widgets::.top17.lab68 {
        array set save {-activebackground 1 -activeforeground 1 -background 1 -borderwidth 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -text 1}
    }
    namespace eval ::widgets::.top17.lab69 {
        array set save {-activebackground 1 -activeforeground 1 -background 1 -borderwidth 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -text 1}
    }
    namespace eval ::widgets::.top17.lab70 {
        array set save {-activebackground 1 -activeforeground 1 -background 1 -borderwidth 1 -foreground 1 -highlightbackground 1 -highlightcolor 1 -relief 1 -text 1}
    }
    namespace eval ::widgets_bindings {
        set tagslist {}
    }
}
}

#################################
# USER DEFINED PROCEDURES
#
#############################################################################
## Procedure:  genfile

proc {genfile} {} {
# Read srvid.csv file
# puts "ErrorCode: $errorCode"
#puts "ERRORINFO:\n$errorInfo\n"

global Export_Name 
global Local_Name
global ProjDir
global Responsible
global Description
global NEntries
global dataList
global errorCode
global LocalEnd
global WorkDir
variable instr
variable fd

set instr "";
set NEntries 0;
set dbdir "";
# "Export_Name,Local_Name,Property,Property_Size,Format, 
#  Property_InSize,InFormat,Property_ID,Access,Num_Modules,Description\n\r" 
#  "EXPORT_NAME,LOCAL_NAME,PROPERTY,PROPERTY_SIZE,FORMAT,PROPERTY_INSIZE, 
#  INFORMAT,PROPERTY_ID,ACCESS,NUM_MODULES,DESCRIPTION"
#setpropid;
set errorCode 0;
#puts "Open file exports.csv";
set dbdir $ProjDir;
#puts "Project dir $dbdir";
set errorCode "0";
catch {cd $dbdir};
if {$errorCode != "0" } {
   exec  mkdir $dbdir; 
  }
  set errorCode "0";
catch {cd $dbdir};
if {$errorCode != "0" } {
     tk_messageBox -message "Couldn't create Project directory. Exit ..." -type ok -icon error ;
     exit;       
  }
cd $dbdir;


catch { set fd [open "exports.csv" "w"] };
if {$errorCode != "0"} {
    puts "Error opening file exports.csv .";
    tk_messageBox -message "Error opening file exports.csv . Exit ..." -type ok -icon error ;
        exit;
  #------ Not reached - not used  ----------
    set fd [open  "exports.csv" "w"];
    set errorCode 0;
    catch { puts $fd "EXPORT_NAME,LOCAL_NAME,PROPERTY,PROPERTY_SIZE,FORMAT,PROPERTY_INSIZE,INFORMAT,PROPERTY_ID,ACCESS,NUM_MODULES,DESCRIPTION\r" };
     if {$errorCode != "0" } {
        close $fd; puts "Error writing exports.csv"; return;
    }
  #-----------------------------------------
 };    
  
close $fd;
set errorCode 0;
catch { exec rm "exports.csv" };
set errorCode 0;
catch { set fd [open "exports.csv" "w"] };
if {$errorCode != "0"} {
    puts "Error opening file exports.csv .";
    tk_messageBox -message "Error opening file exports.csv . Exit ..." -type ok -icon error ;
    cd $WorkDir;
    exit;
        }
#puts "Write file:"
seek $fd 0 start;
foreach x $dataList {
#    puts "$x";
    if { [string length $x] < 1} continue;
    set errorCode 0;
    catch { puts $fd $x};
    if {$errorCode != "0" } {
        close $fd; 
        puts "Error writing exports.csv";
        tk_messageBox -message "Error writing exports.csv . Exit ..." -type ok -icon error ;
        cd $WorkDir;
     exit;
    }
}

close $fd;
#puts "File closed";
if { [lsearch -exact $LocalEnd $Local_Name] < 0} {
lappend LocalEnd $Local_Name;
}
catch { exec srvwizard };
cd $WorkDir;
exit;
}
#############################################################################
## Procedure:  getenv

proc {getenv} {} {
variable envdata
global array env
global Responsible
global Hostname
global HomeDir
global ProjDir
variable envvalue

set envdata "";
set envvalue "";
set ProjDir "";
set Homedir "";

foreach id [array names env] {
#  set envdata "$id: $env($id)"
#  .top17.cpd21.01 insert end $envdata;
#  puts $envdata;
  switch $id  "USER"  { set Responsible $env($id) }  "HOSTNAME" {  set Hostname $env($id) }  "HOME" { append ProjDir $env($id) "/";  .top17.fra19.ent23 delete 0 end;  .top17.fra19.ent23 insert 0 $ProjDir;}
 }; # foreach

set HomeDir $ProjDir;

#getfile
}
#############################################################################
## Procedure:  getfile

proc {getfile} {} {
# Read srvid.csv file
# puts "ErrorCode: $errorCode"
#puts "ERRORINFO:\n$errorInfo\n"

global Export_Name 
global Local_Name
global ProjDir
global Responsible
global Description
global NEntries
global dataList
global Headerstr
global errorCode
global LocalEnd
global PropIDid
variable instr i k
variable fd tmplist
variable tmpstr
variable exportid propid descriptid localid 

set instr "";
set NEntries 0;
set dbdir "";
set dataList {};
set ProjDir [string trim [.top17.fra19.ent23 get]];
#----- Create Local Name ----------

set tmpstr [string range $Export_Name 0 2];
append tmpstr "EQM";
set i 0;
while { [lsearch -exact $LocalEnd $tmpstr] > -1} {
    set tmpstr [string range $Export_Name 0 2];
    append tmpstr "EQ" $i;
     set i [ expr {$i + 1}];
     if { $i > 9 } { break };
} 
set Local_Name $tmpstr;
.top17.fra18.ent26 delete 0 end;
.top17.fra18.ent26 insert 0 $Local_Name;
#----------------------------------
.top17.fra62.cpd17.01 delete 0 end;

# "Export_Name,Local_Name,Property,Property_Size,Format, 
#  Property_InSize,InFormat,Property_ID,Access,Num_Modules,Description\n\r" 
#  "EXPORT_NAME,LOCAL_NAME,PROPERTY,PROPERTY_SIZE,FORMAT,PROPERTY_INSIZE, 
#  INFORMAT,PROPERTY_ID,ACCESS,NUM_MODULES,DESCRIPTION"

set errorCode 0;
#puts "Open file exports.csv";
set dbdir $ProjDir;
#puts "Project dir $dbdir"
set errorCode "0";
catch {cd $dbdir};
if {$errorCode != "0" } {
    return;
#       exec  mkdir $dbdir; 
  }
  set errorCode "0";
catch {cd $dbdir};
if {$errorCode != "0" } {
return;
          tk_messageBox -message "Couldn't create Project directory. Exit ..." -type ok -icon error ;
     exit;       
  }
cd $dbdir;


catch { set fd [open "exports.csv" "r"] };
if {$errorCode != "0"} {
    return;
#    set fd [open  "exports.csv" "w+"];
#    set errorCode 0;
#    catch { puts $fd "EXPORT_NAME,LOCAL_NAME,PROPERTY,PROPERTY_SIZE,FORMAT,PROPERTY_INSIZE,INFORMAT,PROPERTY_ID,ACCESS,NUM_MODULES,DESCRIPTION\r" };
#     if {$errorCode != "0" } {
#        close $fd; puts "Error writing exports.csv"; return;
#    }
 };    


seek $fd 0 start; 
set instr [gets $fd];
#puts "Getfile: first string \n $instr";
if { [string first $Headerstr $instr] < 0 } {
    #puts "Wrong exports file - delete it";
    close $fd;
    catch { exec rm "exports.csv" };
    return;
}
    
set exportid -1;
set propid -1;
set propidid -1;
set descriptid -1;
seek $fd 0 start; 
set NEntries 0;
while { [eof $fd] == 0 } {
  set instr [string trim [gets $fd]];
  if { [string length $instr] < 1 } { continue };
  lappend dataList $instr;
  set NEntries [expr $NEntries + 1]; 
  if { $NEntries == 1 } {
    set tmplist [split $instr ","];
    set i [lsearch -exact $tmplist "EXPORT_NAME"];
    if { $i > -1 } { set exportid $i };  
    set i [lsearch -exact $tmplist "PROPERTY"];
    if { $i > -1 } { set propid $i };
    set i [lsearch -exact $tmplist "PROPERTY_ID"];
    if { $i > -1 } { set PropIDid $i };
    set i [lsearch -exact $tmplist "DESCRIPTION"];
    if { $i > -1 } { set descriptid $i };  
    set i [lsearch -exact $tmplist "LOCAL_NAME"];
    if { $i > -1 } { set localid $i };
#    puts "Export $exportid, property $propid, descript $descriptid";
    continue;
    }
    set tmpstr "";
    set tmplist [split $instr ","];
    if { $exportid > -1 } { if { $propid > -1 } { if { $descriptid > -1 } {
        append tmpstr "\[" [lindex $tmplist $exportid] "\]";
        append tmpstr " " [lindex $tmplist $propid] " ";
        append tmpstr "<" [lindex $tmplist $descriptid] ">"; 
    }}};
#    puts "Get property: $tmpstr";
    
    if { [string length $tmpstr] >0 } { .top17.fra62.cpd17.01 insert end $tmpstr};
       if { $localid > -1 } { .top17.fra18.ent26 delete 0 end;
            set Local_Name [lindex $tmplist $localid];
            .top17.fra18.ent26 insert 0 $Local_Name; } 
};


close $fd;
#puts "File closed, entries $NEntries, size [llength $dataList]";
#if { $NEntries > 0 } { set NEntries [expr $NEntries - 1]; }
#puts "List: $dataList";
#puts "List:"
#foreach x $dataList {
#puts "$x";
#}
#puts "End List";
if { [lsearch -exact $LocalEnd $Local_Name] < 0} {
lappend LocalEnd $Local_Name;
}
}
#############################################################################
## Procedure:  insertAccess

proc {insertAccess} {} {
.top17.fra29.ent41 configure -state normal;
.top17.fra29.ent41 delete 0 end;
.top17.fra29.ent41 insert 0 [.top17.fra29.cpd22.01 get [.top17.fra29.cpd22.01 curselection] ];
.top17.fra29.ent41 configure -state disabled;
bell;
}
#############################################################################
## Procedure:  insertDataInput

proc {insertDataInput} {} {
.top17.fra29.fra30.ent32 configure -state normal;
.top17.fra29.fra30.ent32 delete 0 end;
.top17.fra29.fra30.ent32 insert 0 [.top17.fra29.fra30.cpd24.01 get  [.top17.fra29.fra30.cpd24.01 curselection] ];
.top17.fra29.fra30.ent32 configure -state disabled;
bell;
}
#############################################################################
## Procedure:  insertDataOutput

proc {insertDataOutput} {} {
.top17.fra29.fra36.ent37 configure -state normal;
.top17.fra29.fra36.ent37 delete 0 end;
.top17.fra29.fra36.ent37 insert 0 [.top17.fra29.fra36.cpd25.01 get  [.top17.fra29.fra36.cpd25.01 curselection] ];
.top17.fra29.fra36.ent37 configure -state disabled;
bell;
}
#############################################################################
## Procedure:  insertPrjDir

proc {insertPrjDir} {} {
global HomeDir
global Export_Name
variable tmpstr


set tmpstr $HomeDir;
set Export_Name [string trim [.top17.fra18.ent22 get]];
append tmpstr $Export_Name;
.top17.fra19.ent23 delete 0 end;
.top17.fra19.ent23 insert end $tmpstr;
getfile;
}
#############################################################################
## Procedure:  listadd

proc {listadd} {} {
# Form the property - ExportName+PropName, check if there is the same property in the
# dataList, if yes - return, if no - make the new entry and a string for 
# visible property list and add 

global dataList
global NEntries
global Headerstr
variable tstr k x
global Export_Name
global Property
global Desription
variable tmplist

set tstr "";


set Export_Name [string trim [.top17.fra18.ent22 get]];
set Property [string trim [.top17.fra29.ent39 get]];
#puts "Export $Export_Name, property $Property";

if { [string length $Export_Name] < 1} { return };
if { [string length $Property] < 1} { return };
append Description "\[" [string trim [.top17.fra29.ent42 get]] ":" [string trim [.top17.fra29.ent43 get]] " " [string trim [.top17.fra29.ent44 get]] "\] " [string trim [.top17.fra29.ent40 get]];
foreach x $dataList {
    set tmplist {};
    set k 0;
    #puts "Entry: $x";
    set tmplist [split $x ","];
#    puts "Field: -$Export_Name-";
    if { [lsearch -exact $tmplist $Export_Name] >=0 } { set k [ expr {$k+1}]};
    set tmplist [split $x ","];
    #puts "Field: -$Property-";
    if { [lsearch -exact $tmplist $Property] >=0 } { set k [ expr {$k+1}]};
    #puts "Found $k";
    if { $k > 1 } {
     tk_messageBox -message "This property already created. " -type ok -icon error ; return;   
    };
}
   

set tstr "";
append tstr "\[" $Export_Name  "\]"  " "  $Property  " "  "<" $Description ">" ;
.top17.fra62.cpd17.01 insert end $tstr;    #[.top17.fra19.ent23 get];

#------ 
#------ Make the full entry for the dataList ------

set tstr "";
if { [llength $dataList] < 1 } { 
#puts "Append header: \n $Headerstr";
lappend dataList $Headerstr ;
};

# "Export_Name,Local_Name,Property,Property_Size,Format, 
#  Property_InSize,InFormat,Property_ID,Access,Num_Modules,Description\n\r" 
#set Export_Name [.top17.fra18.ent22 get];
set Local_Name [.top17.fra18.ent26 get];
#set Property [.top17.fra29.ent39 get];
set Property_Size [.top17.fra29.fra36.ent38 get];
set Format [.top17.fra29.fra36.ent37 get];
set Property_InSize [.top17.fra29.fra30.ent35 get];
set InFormat [.top17.fra29.fra30.ent32 get];
#set Property_ID [.top17.fra29.ent39 get];
set Access [.top17.fra29.ent41 get];
set Num_Modules [.top17.fra18.ent28 get];
#set Description [.top17.fra29.ent40 get];
set Property_ID [llength $dataList];

append tstr $Export_Name "," $Local_Name "," $Property "," $Property_Size "," $Format "," $Property_InSize ","  $InFormat "," $Property_ID "," $Access "," $Num_Modules "," $Description;
lappend dataList $tstr;
#puts "After append dataList:\n $dataList";
}
#############################################################################
## Procedure:  removelist

proc {removelist} {} {
global dataList
variable curselect

set errorCode 0;
catch { set curselect [.top17.fra62.cpd17.01 curselection]};
if { $errorCode > 0 } { return };
set errorCode 0;
if { $curselect < 0 } { return };
set errorCode 0;
catch { .top17.fra62.cpd17.01 delete $curselect };
if { $errorCode != 0 } { return };
set curselect [expr {$curselect + 1}];
#puts "Replace index $curselect";
#puts "List element:\n [lindex $dataList $curselect]";
set dataList [lreplace $dataList $curselect $curselect] ;
#puts "After Remove: Datalist:\n $dataList";
}
#############################################################################
## Procedure:  setpropid

proc {setpropid} {} {
global dataList
global errorCode
global PropIDid
variable i x y
variable tmplist
variable tmpstr len


#puts "Prop_IDid $PropIDid";
if { $PropIDid < 0 } { return };
set i 0;
foreach x $dataList { 
if { $i == 0 } { set i [expr {$i+1}]; continue };
set tmpstr $x;
puts "tmpstr before $tmpstr";
set tmplist [split $tmpstr ","];

puts "SetPropId: Prop_ID $PropIDid, list:\n $tmplist";
#set tmplist [lreplace $tmplist $PropIDid $PropIDid $i];
set tmpstr "";
foreach y $tmplist {
    append tmpstr $y ",";

}
puts "tmpstr middle $tmpstr";
set len [string length $tmpstr];
if { $len < 1 } { continue };
set len [expr { $len - 2 }]; 
set tmpstr [string range $tmpstr 0 $len];  
set dataList [lreplace $dataList $i $i $tmpstr] ;
puts "tmpstr after $tmpstr";
set i [expr {$i+1}];

}
}
#############################################################################
## Procedure:  main

proc {main} {argc argv} {
global Export_Name
global Local_Name
global ProjDir
global HomeDir
global Hostname
global ProjName
global PropName
global Property_Size    # out property
global Property_Insize
global Property_ID
global Description
global Access
global Num_Modules
global MinValue
global MaxValue
global Units
global InFormat
global Format
global MaxSizeIn
global MaxSizeOut
global typeslist
global Headerstr
global LocalEnd
global WorkDir
global PropIDid


set PropIDid 0;    # PROPERTY_ID field value
set WorkDir [pwd];
#puts "WorkDir: $WorkDir";
set LocalEnd {};
.top17.fra29.cpd22.01 insert end "READ"
.top17.fra29.cpd22.01 insert end "WRITE"
.top17.fra29.cpd22.01 insert end "READ|WRITE"

set typeslist {};
set typeslist [split "double integer long byte float string Pocalblk Struct NAME16 NAME16fi BIT HITTS NAME32 FLTINT LNGINT DBLINT SHTINT TDS NAME48 NAME8I NAME16I NAME32I NAME48I USTRING FLTFLTINT FILTER IFFF ADDRESS WINDOW POINT TDSI BOOLEAN DEFAULT NULL"];

#puts "Types $typeslist"

#double 
#integer
#long
# byte
# float
# string
# Pocalblk
# Struct
# NAME8
# NAME16
# NAME16fi
# BIT
# HITTS
# NAME32
# FLTINT
# LNGINT
# DBLINT
# SHTINT
# TDS
# NAME48
# NAME8I
# NAME16I
# NAME32I
# NAME48I
# USTRING
# FLTFLTINT
# FILTER
# IFFF
# ADDRESS
# WINDOW
# POINT
# TDSI
# BOOLEAN
# DEFAULT
# NULL

foreach x $typeslist {
#    puts "$x";
    .top17.fra29.fra30.cpd24.01 insert end $x;

}

foreach x $typeslist {
#    puts "$x";
    .top17.fra29.fra36.cpd25.01 insert end $x;

}
.top17.fra18.ent28 insert 0 "1";    # n of devices
.top17.fra29.ent39 insert 0 "TEST";    # property name
.top17.fra29.ent42 insert 0 "100";    # max value
.top17.fra29.ent43 insert 0 "0";    # min value
.top17.fra29.ent44 insert 0 "none";    # units
.top17.fra29.fra30.ent35 insert 0 "0";    # max insize
.top17.fra29.fra36.ent38 insert 0 "100";    # maxoutsize
.top17.fra29.ent41 configure -state normal;
.top17.fra29.ent41 insert 0 "READ";
.top17.fra29.ent41 configure -state disabled;
.top17.fra29.fra30.ent32 configure -state normal;
.top17.fra29.fra30.ent32 insert 0 "NULL";
.top17.fra29.fra30.ent32 configure -state disabled;
.top17.fra29.fra36.ent37 configure -state normal;
.top17.fra29.fra36.ent37 insert 0 "double";
.top17.fra29.fra36.ent37 configure -state disabled;
set Headerstr "EXPORT_NAME,LOCAL_NAME,PROPERTY,PROPERTY_SIZE,FORMAT,PROPERTY_INSIZE,INFORMAT,PROPERTY_ID,ACCESS,NUM_MODULES,DESCRIPTION";

getenv;
}

#############################################################################
## Initialization Procedure:  init

proc {init} {argc argv} {

}

init $argc $argv

#################################
# VTCL GENERATED GUI PROCEDURES
#

proc vTclWindow. {base} {
    if {$base == ""} {
        set base .
    }
    ###################
    # CREATING WIDGETS
    ###################
    wm focusmodel $base passive
    wm geometry $base 1x1+0+0; update
    wm maxsize $base 1009 719
    wm minsize $base 1 1
    wm overrideredirect $base 0
    wm resizable $base 1 1
    wm withdraw $base
    wm title $base "vt.tcl"
    bindtags $base "$base Vtcl.tcl all"
    vTcl:FireEvent $base <<Create>>
    wm protocol $base WM_DELETE_WINDOW "vTcl:FireEvent $base <<DeleteWindow>>"

    ###################
    # SETTING GEOMETRY
    ###################

    vTcl:FireEvent $base <<Ready>>
}

proc vTclWindow.top17 {base} {
    if {$base == ""} {
        set base .top17
    }
    if {[winfo exists $base]} {
        wm deiconify $base; return
    }

    global widget
    vTcl:DefineAlias "$base" "devwizard" vTcl:Toplevel:WidgetProc "" 1
    vTcl:DefineAlias "$base.fra18" "frame1" vTcl:WidgetProc "devwizard" 1
    vTcl:DefineAlias "$base.fra19" "frame2" vTcl:WidgetProc "devwizard" 1
    vTcl:DefineAlias "$base.fra19.ent23" "projentry" vTcl:WidgetProc "devwizard" 1
    vTcl:DefineAlias "$base.fra29" "frame3" vTcl:WidgetProc "devwizard" 1

    ###################
    # CREATING WIDGETS
    ###################
    vTcl:toplevel $base -class Toplevel \
        -background #dcdcdc -highlightbackground #dcdcdc \
        -highlightcolor #000000 
    wm focusmodel $base passive
    wm geometry $base 862x472+107+96; update
    wm maxsize $base 1009 719
    wm minsize $base 1 1
    wm overrideredirect $base 0
    wm resizable $base 1 1
    wm deiconify $base
    wm title $base "Device server setup wizard"
    vTcl:FireEvent $base <<Create>>
    wm protocol $base WM_DELETE_WINDOW "vTcl:FireEvent $base <<DeleteWindow>>"

    frame $base.fra18 \
        -background #dcdcdc -borderwidth 2 -height 75 \
        -highlightbackground #dcdcdc -highlightcolor #000000 -relief groove \
        -width 125 
    label $base.fra18.lab21 \
        -activebackground #f9f9f9 -activeforeground black -background #dcdcdc \
        -borderwidth 0 -foreground #000000 -highlightbackground #dcdcdc \
        -highlightcolor #000000 -relief raised -text {Export Name} 
    entry $base.fra18.ent22 \
        -background #dcdcdc -foreground #000000 -highlightbackground #ffffff \
        -highlightcolor #000000 -insertbackground black \
        -selectbackground #547098 -selectforeground #ffffff 
    bind $base.fra18.ent22 <KeyRelease> {
        insertPrjDir
    }
    label $base.fra18.lab25 \
        -activebackground #f9f9f9 -activeforeground black -background #dcdcdc \
        -borderwidth 0 -foreground #000000 -highlightbackground #dcdcdc \
        -highlightcolor #000000 -relief raised -text {Local Name} 
    entry $base.fra18.ent26 \
        -background #dcdcdc -foreground #000000 -highlightbackground #ffffff \
        -highlightcolor #000000 -insertbackground black \
        -selectbackground #547098 -selectforeground #ffffff 
    label $base.fra18.lab27 \
        -activebackground #f9f9f9 -activeforeground black -background #dcdcdc \
        -borderwidth 0 -foreground #000000 -highlightbackground #dcdcdc \
        -highlightcolor #000000 -relief raised -text {Number of Devices} 
    entry $base.fra18.ent28 \
        -background #dcdcdc -foreground #000000 -highlightbackground #ffffff \
        -highlightcolor #000000 -insertbackground black \
        -selectbackground #547098 -selectforeground #ffffff 
    frame $base.fra19 \
        -background #dcdcdc -borderwidth 2 -height 75 \
        -highlightbackground #dcdcdc -highlightcolor #000000 -relief groove \
        -width 125 
    entry $base.fra19.ent23 \
        -background #dcdcdc -foreground #000000 -highlightbackground #ffffff \
        -highlightcolor #000000 -insertbackground black \
        -selectbackground #547098 -selectforeground #ffffff 
    frame $base.fra29 \
        -background #dcdcdc -borderwidth 2 -height 75 \
        -highlightbackground #dcdcdc -highlightcolor #000000 -relief groove \
        -width 125 
    frame $base.fra29.fra30 \
        -background #dcdcdc -borderwidth 2 -height 75 \
        -highlightbackground #dcdcdc -highlightcolor #000000 -relief groove \
        -width 125 
    entry $base.fra29.fra30.ent32 \
        -background #eaeaea -foreground #000000 -highlightbackground #ffffff \
        -highlightcolor #000000 -insertbackground black \
        -selectbackground #547098 -selectforeground #ffffff -state disabled 
    entry $base.fra29.fra30.ent35 \
        -background #dcdcdc -foreground #000000 -highlightbackground #ffffff \
        -highlightcolor #000000 -insertbackground black \
        -selectbackground #547098 -selectforeground #ffffff 
    frame $base.fra29.fra30.cpd24 \
        -background #dcdcdc -borderwidth 1 -height 30 \
        -highlightbackground #dcdcdc -highlightcolor #000000 -relief raised \
        -width 30 
    listbox $base.fra29.fra30.cpd24.01 \
        -background #000000 \
        -font -Adobe-Helvetica-Medium-R-Normal-*-*-120-*-*-*-*-*-* \
        -foreground #fefefe -highlightbackground #ffffff \
        -highlightcolor #000000 -selectbackground #547098 \
        -selectforeground #ffffff \
        -xscrollcommand "$base.fra29.fra30.cpd24.02 set" \
        -yscrollcommand "$base.fra29.fra30.cpd24.03 set" 
    bind $base.fra29.fra30.cpd24.01 <ButtonRelease-1> {
        insertDataInput
    }
    scrollbar $base.fra29.fra30.cpd24.02 \
        -activebackground #dcdcdc -background #dcdcdc -borderwidth 1 \
        -command "$base.fra29.fra30.cpd24.01 xview" -cursor left_ptr \
        -highlightbackground #dcdcdc -highlightcolor #000000 \
        -orient horizontal -troughcolor #dcdcdc -width 10 
    scrollbar $base.fra29.fra30.cpd24.03 \
        -activebackground #dcdcdc -background #dcdcdc -borderwidth 1 \
        -command "$base.fra29.fra30.cpd24.01 yview" -cursor left_ptr \
        -highlightbackground #dcdcdc -highlightcolor #000000 \
        -troughcolor #dcdcdc -width 10 
    frame $base.fra29.fra36 \
        -background #dcdcdc -borderwidth 2 -height 75 \
        -highlightbackground #dcdcdc -highlightcolor #000000 -relief groove \
        -width 125 
    entry $base.fra29.fra36.ent37 \
        -background #f2f0f4 -foreground #000000 -highlightbackground #ffffff \
        -highlightcolor #000000 -insertbackground black \
        -selectbackground #547098 -selectforeground #ffffff -state disabled 
    entry $base.fra29.fra36.ent38 \
        -background #dcdcdc -foreground #000000 -highlightbackground #ffffff \
        -highlightcolor #000000 -insertbackground black \
        -selectbackground #547098 -selectforeground #ffffff 
    frame $base.fra29.fra36.cpd25 \
        -background #dcdcdc -borderwidth 1 -height 30 \
        -highlightbackground #dcdcdc -highlightcolor #000000 -relief raised \
        -width 30 
    listbox $base.fra29.fra36.cpd25.01 \
        -background #000000 \
        -font -Adobe-Helvetica-Medium-R-Normal-*-*-120-*-*-*-*-*-* \
        -foreground #fefefe -height 0 -highlightbackground #ffffff \
        -highlightcolor #000000 -selectbackground #547098 \
        -selectforeground #ffffff \
        -xscrollcommand "$base.fra29.fra36.cpd25.02 set" \
        -yscrollcommand "$base.fra29.fra36.cpd25.03 set" 
    bind $base.fra29.fra36.cpd25.01 <ButtonRelease-1> {
        insertDataOutput
    }
    scrollbar $base.fra29.fra36.cpd25.02 \
        -activebackground #dcdcdc -background #dcdcdc -borderwidth 1 \
        -command "$base.fra29.fra36.cpd25.01 xview" -cursor left_ptr \
        -highlightbackground #dcdcdc -highlightcolor #000000 \
        -orient horizontal -troughcolor #dcdcdc -width 10 
    scrollbar $base.fra29.fra36.cpd25.03 \
        -activebackground #dcdcdc -background #dcdcdc -borderwidth 1 \
        -command "$base.fra29.fra36.cpd25.01 yview" -cursor left_ptr \
        -highlightbackground #dcdcdc -highlightcolor #000000 \
        -troughcolor #dcdcdc -width 10 
    entry $base.fra29.ent39 \
        -background #dcdcdc -foreground #000000 -highlightbackground #ffffff \
        -highlightcolor #000000 -insertbackground black \
        -selectbackground #547098 -selectforeground #ffffff 
    entry $base.fra29.ent40 \
        -background #dcdcdc -foreground #000000 -highlightbackground #ffffff \
        -highlightcolor #000000 -insertbackground black \
        -selectbackground #547098 -selectforeground #ffffff 
    entry $base.fra29.ent41 \
        -background #ececea -foreground #000000 -highlightbackground #ffffff \
        -highlightcolor #000000 -insertbackground black \
        -selectbackground #547098 -selectforeground #ffffff -state disabled 
    entry $base.fra29.ent42 \
        -background #dcdcdc -foreground #000000 -highlightbackground #ffffff \
        -highlightcolor #000000 -insertbackground black \
        -selectbackground #547098 -selectforeground #ffffff 
    entry $base.fra29.ent43 \
        -background #dcdcdc -foreground #000000 -highlightbackground #ffffff \
        -highlightcolor #000000 -insertbackground black \
        -selectbackground #547098 -selectforeground #ffffff 
    entry $base.fra29.ent44 \
        -background #dcdcdc -foreground #000000 -highlightbackground #ffffff \
        -highlightcolor #000000 -insertbackground black \
        -selectbackground #547098 -selectforeground #ffffff 
    label $base.fra29.lab45 \
        -activebackground #f9f9f9 -activeforeground black -background #dcdcdc \
        -borderwidth 0 -foreground #000000 -highlightbackground #dcdcdc \
        -highlightcolor #000000 -relief raised -text {Property Name} 
    label $base.fra29.lab46 \
        -activebackground #f9f9f9 -activeforeground black -background #dcdcdc \
        -borderwidth 0 -foreground #000000 -highlightbackground #dcdcdc \
        -highlightcolor #000000 -relief raised -text Description 
    label $base.fra29.lab47 \
        -activebackground #f9f9f9 -activeforeground black -background #dcdcdc \
        -borderwidth 0 -foreground #000000 -highlightbackground #dcdcdc \
        -highlightcolor #000000 -relief raised -text Access 
    label $base.fra29.lab48 \
        -activebackground #f9f9f9 -activeforeground black -background #dcdcdc \
        -borderwidth 0 -foreground #000000 -highlightbackground #dcdcdc \
        -highlightcolor #000000 -relief raised -text {Max Value} 
    label $base.fra29.lab49 \
        -activebackground #f9f9f9 -activeforeground black -background #dcdcdc \
        -borderwidth 0 -foreground #000000 -highlightbackground #dcdcdc \
        -highlightcolor #000000 -relief raised -text {Min Value} 
    label $base.fra29.lab52 \
        -activebackground #f9f9f9 -activeforeground black -background #dcdcdc \
        -borderwidth 0 -foreground #000000 -highlightbackground #dcdcdc \
        -highlightcolor #000000 -relief raised -text Units 
    label $base.fra29.lab53 \
        -activebackground #f9f9f9 -activeforeground black -background #dcdcdc \
        -borderwidth 0 -foreground #000000 -highlightbackground #dcdcdc \
        -highlightcolor #000000 -relief raised -text {Data Format} 
    label $base.fra29.lab54 \
        -activebackground #f9f9f9 -activeforeground black -background #dcdcdc \
        -borderwidth 0 -foreground #000000 -highlightbackground #dcdcdc \
        -highlightcolor #000000 -relief raised -text {Max Data Size} 
    label $base.fra29.lab71 \
        -activebackground #f9f9f9 -activeforeground black -background #dcdcdc \
        -borderwidth 0 -foreground #000000 -highlightbackground #dcdcdc \
        -highlightcolor #000000 -relief raised -text {Data Input} 
    label $base.fra29.lab72 \
        -activebackground #f9f9f9 -activeforeground black -background #dcdcdc \
        -borderwidth 0 -foreground #000000 -highlightbackground #dcdcdc \
        -highlightcolor #000000 -relief raised -text {Data Output} 
    frame $base.fra29.cpd22 \
        -background #dcdcdc -borderwidth 1 -height 30 \
        -highlightbackground #dcdcdc -highlightcolor #000000 -relief raised \
        -width 30 
    listbox $base.fra29.cpd22.01 \
        -background #707276 \
        -font -Adobe-Helvetica-Medium-R-Normal-*-*-120-*-*-*-*-*-* \
        -foreground #fefefe -highlightbackground #ffffff \
        -highlightcolor #000000 -selectbackground #547098 \
        -selectforeground #ffffff -xscrollcommand "$base.fra29.cpd22.02 set" \
        -yscrollcommand "$base.fra29.cpd22.03 set" 
    bind $base.fra29.cpd22.01 <ButtonRelease-1> {
        insertAccess
    }
    scrollbar $base.fra29.cpd22.02 \
        -activebackground #dcdcdc -background #dcdcdc -borderwidth 1 \
        -command "$base.fra29.cpd22.01 xview" -cursor left_ptr \
        -highlightbackground #dcdcdc -highlightcolor #000000 \
        -orient horizontal -troughcolor #dcdcdc -width 10 
    scrollbar $base.fra29.cpd22.03 \
        -activebackground #dcdcdc -background #dcdcdc -borderwidth 1 \
        -command "$base.fra29.cpd22.01 yview" -cursor left_ptr \
        -highlightbackground #dcdcdc -highlightcolor #000000 \
        -troughcolor #dcdcdc -width 10 
    checkbutton $base.che60 \
        -activebackground #dcdcdc -activeforeground #000000 \
        -background #dcdcdc -foreground #000000 -highlightbackground #dcdcdc \
        -highlightcolor #000000 -text C-project -variable che60 
    checkbutton $base.che61 \
        -activebackground #dcdcdc -activeforeground #000000 \
        -background #dcdcdc -foreground #000000 -highlightbackground #dcdcdc \
        -highlightcolor #000000 -text check -variable che61 
    frame $base.fra62 \
        -background #dcdcdc -borderwidth 2 -height 75 \
        -highlightbackground #dcdcdc -highlightcolor #000000 -relief groove \
        -width 125 
    frame $base.fra62.cpd17 \
        -background #dcdcdc -borderwidth 1 -height 30 \
        -highlightbackground #dcdcdc -highlightcolor #000000 -relief raised \
        -width 30 
    listbox $base.fra62.cpd17.01 \
        -background #dcdcdc \
        -font -Adobe-Helvetica-Medium-R-Normal-*-*-120-*-*-*-*-*-* \
        -foreground #000000 -highlightbackground #ffffff \
        -highlightcolor #000000 -selectbackground #547098 \
        -selectforeground #ffffff -xscrollcommand "$base.fra62.cpd17.02 set" \
        -yscrollcommand "$base.fra62.cpd17.03 set" 
    bind $base.fra62.cpd17.01 <Double-ButtonRelease-1> {
        removelist
    }
    bind $base.fra62.cpd17.01 <Key> {
        bell;
    }
    bind $base.fra62.cpd17.01 <KeyRelease> {
        bell;
bell;
    }
    scrollbar $base.fra62.cpd17.02 \
        -activebackground #dcdcdc -background #dcdcdc -borderwidth 1 \
        -command "$base.fra62.cpd17.01 xview" -cursor left_ptr \
        -highlightbackground #dcdcdc -highlightcolor #000000 \
        -orient horizontal -troughcolor #dcdcdc -width 10 
    scrollbar $base.fra62.cpd17.03 \
        -activebackground #dcdcdc -background #dcdcdc -borderwidth 1 \
        -command "$base.fra62.cpd17.01 yview" -cursor left_ptr \
        -highlightbackground #dcdcdc -highlightcolor #000000 \
        -troughcolor #dcdcdc -width 10 
    button $base.fra62.but19 \
        -activebackground #dcdcdc -activeforeground #000000 \
        -background #dcdcdc -command removelist -foreground #000000 \
        -highlightbackground #dcdcdc -highlightcolor #000000 -text Remove 
    button $base.fra62.but20 \
        -activebackground #dcdcdc -activeforeground #000000 \
        -background #dcdcdc -command listadd -foreground #000000 \
        -highlightbackground #dcdcdc -highlightcolor #000000 -text Add 
    button $base.fra62.but21 \
        -activebackground #dcdcdc -activeforeground #000000 \
        -background #dcdcdc -command genfile -foreground #000000 \
        -highlightbackground #dcdcdc -highlightcolor #000000 -text Done 
    bind $base.fra62.but21 <ButtonRelease-1> {
        genfile
    }
    label $base.lab68 \
        -activebackground #f9f9f9 -activeforeground black -background #dcdcdc \
        -borderwidth 0 -foreground #000000 -highlightbackground #dcdcdc \
        -highlightcolor #000000 -relief raised -text {Property Information} 
    label $base.lab69 \
        -activebackground #f9f9f9 -activeforeground black -background #dcdcdc \
        -borderwidth 0 -foreground #000000 -highlightbackground #dcdcdc \
        -highlightcolor #000000 -relief raised \
        -text {Device Server Information} 
    label $base.lab70 \
        -activebackground #f9f9f9 -activeforeground black -background #dcdcdc \
        -borderwidth 0 -foreground #000000 -highlightbackground #dcdcdc \
        -highlightcolor #000000 -relief raised -text {Project directory} 
    ###################
    # SETTING GEOMETRY
    ###################
    place $base.fra18 \
        -x 5 -y 35 -width 635 -height 50 -anchor nw -bordermode ignore 
    place $base.fra18.lab21 \
        -x 10 -y 15 -anchor nw -bordermode ignore 
    place $base.fra18.ent22 \
        -x 95 -y 15 -width 93 -height 22 -anchor nw -bordermode ignore 
    place $base.fra18.lab25 \
        -x 210 -y 15 -anchor nw -bordermode ignore 
    place $base.fra18.ent26 \
        -x 290 -y 15 -width 93 -height 22 -anchor nw -bordermode ignore 
    place $base.fra18.lab27 \
        -x 410 -y 15 -anchor nw -bordermode ignore 
    place $base.fra18.ent28 \
        -x 535 -y 15 -width 93 -height 22 -anchor nw -bordermode ignore 
    place $base.fra19 \
        -x 650 -y 35 -width 205 -height 50 -anchor nw -bordermode ignore 
    place $base.fra19.ent23 \
        -x 10 -y 15 -width 183 -height 22 -anchor nw -bordermode ignore 
    place $base.fra29 \
        -x 5 -y 110 -width 600 -height 345 -anchor nw -bordermode ignore 
    place $base.fra29.fra30 \
        -x 115 -y 195 -width 140 -height 135 -anchor nw -bordermode ignore 
    place $base.fra29.fra30.ent32 \
        -x 10 -y 5 -width 118 -height 22 -anchor nw -bordermode ignore 
    place $base.fra29.fra30.ent35 \
        -x 10 -y 105 -width 118 -height 22 -anchor nw -bordermode ignore 
    place $base.fra29.fra30.cpd24 \
        -x 10 -y 25 -width 120 -height 70 -anchor nw -bordermode ignore 
    grid columnconf $base.fra29.fra30.cpd24 0 -weight 1
    grid rowconf $base.fra29.fra30.cpd24 0 -weight 1
    grid $base.fra29.fra30.cpd24.01 \
        -in $base.fra29.fra30.cpd24 -column 0 -row 0 -columnspan 1 -rowspan 1 \
        -sticky nesw 
    grid $base.fra29.fra30.cpd24.02 \
        -in $base.fra29.fra30.cpd24 -column 0 -row 1 -columnspan 1 -rowspan 1 \
        -sticky ew 
    grid $base.fra29.fra30.cpd24.03 \
        -in $base.fra29.fra30.cpd24 -column 1 -row 0 -columnspan 1 -rowspan 1 \
        -sticky ns 
    place $base.fra29.fra36 \
        -x 265 -y 195 -width 145 -height 135 -anchor nw -bordermode ignore 
    place $base.fra29.fra36.ent37 \
        -x 10 -y 5 -width 123 -height 22 -anchor nw -bordermode ignore 
    place $base.fra29.fra36.ent38 \
        -x 10 -y 105 -width 123 -height 22 -anchor nw -bordermode ignore 
    place $base.fra29.fra36.cpd25 \
        -x 10 -y 25 -width 125 -height 70 -anchor nw -bordermode ignore 
    grid columnconf $base.fra29.fra36.cpd25 0 -weight 1
    grid rowconf $base.fra29.fra36.cpd25 0 -weight 1
    grid $base.fra29.fra36.cpd25.01 \
        -in $base.fra29.fra36.cpd25 -column 0 -row 0 -columnspan 1 -rowspan 1 \
        -sticky nesw 
    grid $base.fra29.fra36.cpd25.02 \
        -in $base.fra29.fra36.cpd25 -column 0 -row 1 -columnspan 1 -rowspan 1 \
        -sticky ew 
    grid $base.fra29.fra36.cpd25.03 \
        -in $base.fra29.fra36.cpd25 -column 1 -row 0 -columnspan 1 -rowspan 1 \
        -sticky ns 
    place $base.fra29.ent39 \
        -x 120 -y 30 -width 178 -height 22 -anchor nw -bordermode ignore 
    place $base.fra29.ent40 \
        -x 410 -y 30 -width 163 -height 22 -anchor nw -bordermode ignore 
    place $base.fra29.ent41 \
        -x 75 -y 75 -width 128 -height 22 -anchor nw -bordermode ignore 
    place $base.fra29.ent42 \
        -x 305 -y 75 -width 83 -height 22 -anchor nw -bordermode ignore 
    place $base.fra29.ent43 \
        -x 490 -y 75 -width 83 -height 22 -anchor nw -bordermode ignore 
    place $base.fra29.ent44 \
        -x 490 -y 200 -width 83 -height 22 -anchor nw -bordermode ignore 
    place $base.fra29.lab45 \
        -x 15 -y 30 -anchor nw -bordermode ignore 
    place $base.fra29.lab46 \
        -x 330 -y 30 -anchor nw -bordermode ignore 
    place $base.fra29.lab47 \
        -x 25 -y 75 -anchor nw -bordermode ignore 
    place $base.fra29.lab48 \
        -x 230 -y 75 -anchor nw -bordermode ignore 
    place $base.fra29.lab49 \
        -x 420 -y 75 -anchor nw -bordermode ignore 
    place $base.fra29.lab52 \
        -x 445 -y 200 -anchor nw -bordermode ignore 
    place $base.fra29.lab53 \
        -x 25 -y 200 -anchor nw -bordermode ignore 
    place $base.fra29.lab54 \
        -x 15 -y 300 -anchor nw -bordermode ignore 
    place $base.fra29.lab71 \
        -x 140 -y 175 -anchor nw -bordermode ignore 
    place $base.fra29.lab72 \
        -x 280 -y 175 -anchor nw -bordermode ignore 
    place $base.fra29.cpd22 \
        -x 75 -y 95 -width 130 -height 70 -anchor nw -bordermode ignore 
    grid columnconf $base.fra29.cpd22 0 -weight 1
    grid rowconf $base.fra29.cpd22 0 -weight 1
    grid $base.fra29.cpd22.01 \
        -in $base.fra29.cpd22 -column 0 -row 0 -columnspan 1 -rowspan 1 \
        -sticky nesw 
    grid $base.fra29.cpd22.02 \
        -in $base.fra29.cpd22 -column 0 -row 1 -columnspan 1 -rowspan 1 \
        -sticky ew 
    grid $base.fra29.cpd22.03 \
        -in $base.fra29.cpd22 -column 1 -row 0 -columnspan 1 -rowspan 1 \
        -sticky ns 
    place $base.fra62 \
        -x 610 -y 110 -width 245 -height 345 -anchor nw -bordermode ignore 
    place $base.fra62.cpd17 \
        -x 5 -y 5 -width 230 -height 280 -anchor nw -bordermode ignore 
    grid columnconf $base.fra62.cpd17 0 -weight 1
    grid rowconf $base.fra62.cpd17 0 -weight 1
    grid $base.fra62.cpd17.01 \
        -in $base.fra62.cpd17 -column 0 -row 0 -columnspan 1 -rowspan 1 \
        -sticky nesw 
    grid $base.fra62.cpd17.02 \
        -in $base.fra62.cpd17 -column 0 -row 1 -columnspan 1 -rowspan 1 \
        -sticky ew 
    grid $base.fra62.cpd17.03 \
        -in $base.fra62.cpd17 -column 1 -row 0 -columnspan 1 -rowspan 1 \
        -sticky ns 
    place $base.fra62.but19 \
        -x 5 -y 295 -anchor nw -bordermode ignore 
    place $base.fra62.but20 \
        -x 95 -y 295 -anchor nw -bordermode ignore 
    place $base.fra62.but21 \
        -x 175 -y 295 -anchor nw -bordermode ignore 
    place $base.lab68 \
        -x 15 -y 100 -width 146 -height 18 -anchor nw -bordermode ignore 
    place $base.lab69 \
        -x 15 -y 25 -width 166 -height 18 -anchor nw -bordermode ignore 
    place $base.lab70 \
        -x 660 -y 25 -width 121 -height 18 -anchor nw -bordermode ignore 

    vTcl:FireEvent $base <<Ready>>
}

Window show .
Window show .top17

main $argc $argv
